@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: uuid
 version: 1.3.12
-id: uuid-1.3.12-84f229c814727c5af1ad08339e489d01
-key: uuid_4hPK7QrBrnCBnkNJqrd93M
+id: uuid-1.3.12-2d400ebaa361b94ddb33df85f93ca791
+key: uuid_6PwFfHICNju0Ut9rrA496c
 license: BSD3
 copyright: (c) 2008-2014 Antoine Latter
 maintainer: aslatter@gmail.com
@@ -24,13 +24,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-1.3.12
 library-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-1.3.12
 data-dir: /usr/share/arm-linux-ghc-7.10.3/uuid-1.3.12
-hs-libraries: HSuuid-1.3.12-4hPK7QrBrnCBnkNJqrd93M
+hs-libraries: HSuuid-1.3.12-6PwFfHICNju0Ut9rrA496c
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    cryptonite-0.13-349d06636b05d6ecd7f57ca79abfe077
-    memory-0.11-3a745e41fe78387f608c420e9b455d25
+    cryptonite-0.15-52f487cbd51518538a9e7cbc4eddf82b
+    memory-0.12-092368f288b8a5ed89de3a4f849c43f2
     network-info-0.2.0.8-bc6c8aa48b93ac2c06aa2e5c4fa39eb6
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
